Index: src/compiler/node.h |
diff --git a/src/compiler/node.h b/src/compiler/node.h |
index e6c9f23fdc4daf1385bad1e11febe321e0fbacc8..bd129653bc3397510a53169c0ce48ae9ef411004 100644 |
--- a/src/compiler/node.h |
+++ b/src/compiler/node.h |
@@ -284,9 +284,9 @@ class Node final { |
void* operator new(size_t, void* location) { return location; } |
- // Only NodeProperties should manipulate the bounds. |
- Bounds bounds() const { return bounds_; } |
- void set_bounds(Bounds b) { bounds_ = b; } |
+ // Only NodeProperties should manipulate the type. |
+ Type* type() const { return type_; } |
+ void set_type(Type* type) { type_ = type; } |
// Only NodeMarkers should manipulate the marks on nodes. |
Mark mark() { return mark_; } |
@@ -306,7 +306,7 @@ class Node final { |
static const int kMaxInlineCapacity = InlineCapacityField::kMax - 1; |
const Operator* op_; |
- Bounds bounds_; |
+ Type* type_; |
Mark mark_; |
uint32_t bit_field_; |
Use* first_use_; |